@@ -14,7 +14,9 @@ utils::globalVariables(
     "model",
     "non_hdl_c",
     "outcome",
+    "outcome_and_model",
     "over_years",
+    "preventr_id",
     "pt_est",
     "repeated",
     "risk_group",
